function dta2fli(pngfiles,animfile,dtadir,options)
%DTA2FLI   Create FLI/FLC animations on Windows
%   DTA2FLI(PNG_FILES,ANIM_FILE,DTA_DIR,OPTIONS)
%   Uses David K. Mason DTA.EXE to create FLC or AVI animation
%   input:
%      PNG_FILES   images selection [ 'image*.png' ]
%      ANIM_FILE   animation name [ 'anim' ]
%      DTA_DIR     dta.exe directory
%      OPTIONS     options of DTA.EXE   [ <none> ]
%
%   comment:
%      Windows program DTA.EXE must be available
%      It can be obtained at:
%      http://www.povray.org/ftp/pub/povray/utilities/dta/
%      This function runs on Windows,
%      for UNIX like machines use PPM2FLI instead
%      For more detailed information about creation and visualisation
%      of FLI/FLC animations, see the site:
%      http://neptuno.fis.ua.pt/~mma/etc/anims/anims.htm
%
%   example:
%      dta2fli('my_images*.png','myanim','c:\dta\');
%
%   MMA 7-7-2004, martinho@fis.ua.pt
%
%   See also PPM2FLI, GET_TIFF, FIXEDAR, TIFF2PPM, APPEND_ANIM

if nargin < 4
  options='';
end
if nargin < 3
  disp('## more arguments needed...');
  return
end

% create images list:
d=dir(pngfiles);
if isempty(d)
  disp(['## warning: no files matching ',pngfiles]);
  return
end
tmp_list = 'lista.txt';
fid=fopen(tmp_list,'w');
fprintf(fid,'%s\r',d.name);
fclose(fid);

% search for dta.exe on dtadir:
dta=[dtadir,'dta.exe'];
if isempty(dir(dta))
  disp(['## warning: dta.exe not found in ',dtadir]);
  delete(tmp_list)
  return
end

% I wanna Command Prompt to close after animation is created, so
% will use bat file with close in last line:
bat_tmp='batfile.bat';
fid=fopen(bat_tmp,'w');
fprintf(fid,'%s @%s /O%s\n',dta,tmp_list,animfile,options);
fprintf(fid,'exit');
fclose(fid);

% create animation:
eval(['! ',bat_tmp,' &']);

% remove temporary files:
pause(1)
delete(tmp_list);
delete(bat_tmp);

disp(' ')
disp(['## done, created ',animfile,'.flc']);
disp(' ')
