function get_tiff(T,image_name,format,options,convert_format,convert_opts)
%GET_TIFF   Print current image
%   GET_TIFF(T,IMAGE_NAME,FORMAT,OPTIONS,CONVERT_FORMAT,CONVERT_OPTS)
%   Useful in loops generating images, prints current image to a certain
%   format and can convert to another using the ImageMagick convert
%
%   input:
%      T                 image index, image_name_00...T.format [ {0} ... n ]
%      IMAGE_NAME        name of printed image [ 'image' ]
%      FORMAT            printed image format [ 'tif' ]
%      OPTIONS           matlab print options [ '-dtiff -r0 -zbuffer' ]
%      CONVERT_FORMAT    convert format [ 'ppm' ]
%      CONVERT_OPTS      ImageMagick convert options [ <none> ]
%
%   result:
%      images, converted images
%
%   comment:
%     -r0 specifies screen resolution
%     if this option is used, printed image size will be similar to
%     image on screen cos FIXEDAR is applied
%     -zbuffer will more likely give you output that emulates the screen
%
%   requires:
%      ImageMagick convert must be installed, if convert will be used
%      ImageMagick is available at:
%      http://www.imagemagick.org/
%
%   example:
%      get_tiff(1,'image','ps','-dpsc2 -loose');
%      get_tiff(1,'image','tif','-dtiff -r0 -zbuffer','ppm','-geometry 70%');
%      get_tiff(1,'image','png','-dpng  -r0 -zbuffer');
%
%   MMA 16-11-2002, martinho@fis.ua.pt
%   Revision 10-2003
%   Modified 7-7-2004
%
%   See also FIXEDAR, TIFF2PPM, PPM2FLI, APPEND_ANIM

if nargin < 6
  convert_opts ='';
end
if nargin < 5
  convert_format='';
end
if nargin < 4 
  options='-dtiff -r0 -zbuffer';
end
if nargin < 3
  format='tif';
end
if nargin < 2
  image_name='image';
end
if nargin < 1
  T=0;
end

if T<10
  fname=[image_name,'_000',int2str(T),'.',format];
elseif T<100
  fname=[image_name,'_00',int2str(T),'.',format];
elseif T<1000
  fname=[image_name,'_0',int2str(T),'.',format];
else
  fname=[image_name,'_',int2str(T),'.',format];
end

% FIXEDAR:
if ~isempty(findstr(' -r0 ',options))
  eval('fixedar');
end

printstr=['print ',options,'  ',fname];
eval(printstr);

if ~isempty(convert_format)
  % search for ImageMagick convert:
  [s]=evalc('! convert');
  if isempty(findstr('ImageMagick',s))
    disp('## ImageMagick convert not found... convert not done')
    return
  end

  evalstr=['! convert ',convert_opts,' ',fname,' ',fname(1:end-length(format)),convert_format];
  eval(evalstr);
end
