function ppm2fli(ppmfiles,anim_file,fps,size,options);
%PPM2FLI   Create FLI/FLC animations on UNIX like machines
%   PPM2FLI(PPM_FILES,ANIM_FILE,FPS,SIZE,OPTIONS)
%   Uses UNIX ppm2fli to create FLI/FLC animation
%
%   input:
%      PPM_FILES   images selection [ '*.ppm' ]
%      ANIM_FILE   animation name [ 'anim.flc' ]
%      FPS         frames per second [ 5 ]
%      SIZE        animation size [ <width x hight> {<none>} ]
%      OPTIONS     options of the unix ppm2fli   [ <none> ]
%
%   comment:
%      unix ppm2fli must be installed
%      ppm2fli  is available at:
%      http://vento.pi.tu-berlin.de/fli.html
%      This function runs on UNIX like machines,
%      for Windows use DTA2FLI instead
%      For more detailed information about creation and visualisation
%      of FLI/FLC animations, see the site:
%      http://neptuno.fis.ua.pt/~mma/etc/anims/anims.htm
%
%   example:
%      ppm2fli('*.ppm','anim.flc',5,'300x500');
%
%   MMA 19-11-2002, martinho@fis.ua.pt
%   Revision 10-2003
%   Modified 7-7-2004
%
%   See also DTA2FLI, GET_TIFF, FIXEDAR, TIFF2PPM, APPEND_ANIM

if nargin < 5
  options=' ';
end
if nargin < 4 
  size=' ';
else
  size=['-g ',size];
end
if nargin < 3
  fps=4;
end
if nargin < 2
  anim_file='anim.flc';
end
if nargin < 1
  ppmfiles='*.ppm';
end

speed=1000/fps;
s=['-s ',num2str(speed)];

unix(['ls -1 ',ppmfiles,' > lista']);
unix(['ppm2fli ',s,' ',size,' -N lista ',options,' ',anim_file]);
unix('rm lista');
%unix(['rm ',ppmfiles]);
