function resize_anim(anim,geometry,g,fps)
%RESIZE_ANIM   Resize FLI/FLC animation
%   RESIZE_ANIM(ANIM,GEOMETRY,G,FPS)
%
%   input:
%      ANIM       FLI/FLC animations to join (side by side)
%      GEOMETRY   convert geometry [ {'100%'} WxH(%) ]
%      G          size of final anim [ <width x height> {<none>} ]
%      FPS        frames per second of final animation [ 5 ]
%
%   result:
%      anim_resized.flc
%
%   comment:
%      ppm2fli, unflick and convert need to be installed
%      runs on unix like machines
%
%   example:
%      resize_anim('anim.flc','70%','600x300',5)
%
%   MMA 16-7-2004, martinho@fis.ua.pt
%
%   See also APPEND_ANIM

anim_file='anim_resized.flc';

if nargin < 4
  fps=5;
end
if nargin < 3
  g='';
else
 g=['-g ',g];
end
if nargin < 2
  disp('# nothing to do...');
  return
end

unix(['unflick ',anim,' anim_1']);

lista_1=ls(['-1 anim_1.*',]);

a=find(lista_1=='.');
if length(a) == 1
  l=length(lista_1)
else
  l=a(2)-a(1);
end

N=length(a);
for i=1:N
  name_1(i,:)=lista_1(1+l*(i-1):l*i-1);
end

for i=1:N
  disp(['# resizing ', name_1(i,:)]);
  unix(['convert -geometry ',geometry,' ', name_1(i,:),' ',name_1(i,:)]);
end

speed=1000/fps;
s=['-s ',num2str(speed)];
unix(['ls -1 anim_1.* > lista']);
unix(['ppm2fli ',g,' ',s,'  -N lista ',anim_file]);

unix(['rm anim_1.*']);
unix(['rm lista']);
