function tiff2ppm(options,tif,ppm);
%TIFF2PPM   Convert image (tif) to another (ppm)
%   TIFF2PPM(OPTIONS,TIF,PPM)
%   Uses ImageMagick convert to obtain image in other format
%
%   input:
%      OPTIONS   ImageMagick convert options [ <none> ]
%      TIF       original image extension [ 'tif' ]
%      PPM       final image format [ 'ppm' ]
%
%   requires:
%      ImageMagick convert must be installed
%      ImageMagick is available at:
%      http://www.imagemagick.org/
%
%   comment:
%      all images in current dir with extension TIF will be used
%
%   example:
%      tiff2ppm('-geometry 70%')
%
%   MMA 16-11-2002, martinho@fis.ua.pt
%   Revision 10-2003
%   Modified 7-7-2004
%
%   See also GET_TIFF, FIXEDAR, PPM2FLI, APPEND_ANIM

if nargin < 3
  ppm='ppm';
end
if nargin < 2
  tif='tif';
end
if nargin < 1
  options=' ';
end

d=dir(['*.',tif]);
lista=struct2cell(d);
if isempty(lista)
  disp(['## no ',tif,' files found...']);
  return
end
lista=lista(1,:);

% search for ImageMagick convert:
[s]=evalc('! convert');
if isempty(findstr('ImageMagick',s))
  disp('## ImageMagick convert not found... convert not done')
  return
end

lista2 = strrep(lista,tif,ppm);
for i=1:length(lista)
  name1 = lista{i};
  name2 = lista2{i};
  disp(['# convert ', name1,' to ',name2]); 
  eval(['! convert ',options,' ',name1,' ',name2]);
end
