function copy_figure(CurrentAxis,NewAxis,name,invert)
%COPY_FIGURE   Copy objects of an axis to another
%   COPY_FIGURE(AXIS,NEW_AXIS,NAME,INVERT)
%
%   input:
%      AXIS       axis to copy [ <current> ]
%      NEW_AXIS   destination axis [ <figure,axes> ]
%      NAME       title on new figure [ 'copy of' ]
%      INVERT     make flipud of objects during copy [ {0} | 1 ]
%
%   example:
%      figure
%      plot(1:10), hold on
%      plot(2:15,'r*'); pcolor(rand(3))
%      copy_figure
%      xlabel('testing...')
%      old=gca;
%      figure, new=axes;
%      copy_figure(old, new,'just another copy')
%
%   MMA Jul-2003, martinho@fis.ua.pt
%   Revision 10-2003

if nargin ==0
    CurrentAxis=gca;
end
if nargin < 4
  invert=0;
end
if nargin < 3
    name='copy';
end
if nargin < 2
    figure
    NewAxis=axes;
end
set(gcf,'numbertitle','off','name',name);

objects=get(CurrentAxis,'children');
if invert
  objects=flipud(objects);
end

CopiedHandles=copyobj(objects,CurrentAxis);

for i=length(CopiedHandles):-1:1
    set(CopiedHandles(i),'parent',NewAxis);
end

return
% also copy labels: this may not be needed... if labels are part of axis
% children
label_x = get(CurrentAxis,'xlabel'); int_x = get(label_x,'Interpreter');
label_y = get(CurrentAxis,'ylabel'); int_y = get(label_y,'Interpreter');
label_z = get(CurrentAxis,'zlabel'); int_z = get(label_z,'Interpreter');
label_t = get(CurrentAxis,'title');  int_t = get(label_t,'Interpreter');

xlabel(get(label_x,'string'),'interpreter',int_x);
ylabel(get(label_y,'string'),'interpreter',int_y);
zlabel(get(label_z,'string'),'interpreter',int_z);
title(get(label_t,'string'),'interpreter',int_t);
