function handle=cyl(P0,P1,r,fcolor,ecolor)
%CYL   Draw cylinder
%   HANDLE = CYL(P0,P1,R,FCOLOR.ECOLOR)
%
%   input:
%      P0       initial position [ <x y z> ]
%      P1       end of cylinder [ <x y z> ]
%      R        radius  [ <r> ]
%      FCOLOR   FaceColor [ 'none' ]
%      ECOLOR   EdgeColor [ 'r' ]
%
%   output:
%      HANDLE   surf handle
%
%   example:
%      figure
%      cyl([0 0 0],[10 20 5],1), axis equal
%      axis([-2 12 -2 22 -2 7]), box on
%      view([12 14]);
%
%   MMA 6-2004, martinho@fis.ua.pt
%
%   See also SPH, SPH2

if nargin < 5
  ecolor = 'r';
end
if nargin < 4
  fcolor = 'none';
end

% divisions  (number of rectangles)
nd= 20;

tmp=P1-P0;
[tet,fi,L]=cart2sph(tmp(1),tmp(2),tmp(3));
tet=tet*180/pi;
fi=fi*180/pi;fi=fi-90;

tt=linspace(0,2*pi,nd);
%circ:
xc=r*sin(tt);
yc=r*cos(tt);
zc=0*ones(size(yc));

xc2=xc;
yc2=yc;
zc2=zc+L;

for i=1:length(xc)
  v=[xc(i) yc(i) zc(i)]';
  vv=[xc2(i) yc2(i) zc2(i)]';

  v2=rot3d(v,tet,fi);
  vv=rot3d(vv,tet,fi);

  x(i) = v2(1); y(i) =v2(2); z(i) =v2(3);
  xx(i)= vv(1); yy(i)=vv(2); zz(i)=vv(3);
end

X=[x; xx]+P0(1);
Y=[y; yy]+P0(2);
Z=[z; zz]+P0(3);

h=ishold;
hold on
handle=surf(X,Y,Z);
set(handle,'facecolor',fcolor);
set(handle,'edgecolor',ecolor);

% line inside cylinder:
%plot3([P0(1) P1(1)],[P0(2) P1(2)],[P0(3) P1(3)],'r-')

if ~h
  hold off
end
