function handle = myhist(x,y,dx,dy,FaceColor,EdgeColor)
%MYHIST   Histogram, another version
%   HANDLE = MYHIST(X,Y,DX,DY,FaceColor,EdgeColor)
%   Does not calculates data, it is just a drawing utility
%   Draws histogram with defined x, so data length = x length -1
%   or, if lengths are equal, bars are centred in x
%
%   input:
%      X          x locations
%      Y          data
%      DX, DY     offset added to bars
%      FaceColor  bars FaceColor [ 'y' ]
%      EdgeColor  bars EdgeColor [ 'r' ]
%
%   output:
%      handles   handle to fiil objects
%
%   example:
%      x= [10 11 13 17 18];
%      y =[3 7 2 3];
%      figure,
%      handle = myhist(x,y);
%
%   MMA 8-10-2004, martinho@fis.ua.pt

handle=[];

if nargin < 6
  EdgeColor = 'r';
end
if nargin < 5
  FaceColor = 'y';
end
if nargin < 4
  dy = 0;
end
if nargin < 3
  dx = 0;
end
if nargin < 2
  y = x;
  x=1:length(y);
end
if nargin < 1
  disp('# nothing to do...');
end

% check lengths:
nx = length(x);
ny = length(y);

if nx == ny
  x_ = (x(2:end)+x(1:end-1))/2;
  dx1 = x_(1) - x(1);
  dxe = x(end) - x_(end);
  x = [x(1)-dx1 x_ x(end)+dxe];
elseif nx ~= ny+1
  disp('# wrong lengths of x and y, nx=ny or nx=ny+1, only')
end

h = ishold;
hold on
for i=1:length(x)-1
  xx = [x(i) x(i+1) x(i+1) x(i) x(i) ] + dx;
  yy = [0    0      y(i)   y(i) 0    ] + dy;

  handle{i} = fill(xx,yy,FaceColor);
  set(handle{i},'EdgeColor',EdgeColor);
end

if ~h
  hold off
end
