function handle = mystem(x,y,r,options)
%MYSTEM   Modified version of stem
%   HANDLE = MYSTEM(X,Y,R,OPTIONS)
%   Creates a plot similar to stem, but using a line of length 2*r as marker
%
%   input:
%      X         vector x
%      Y         vector y=f(x)
%      R         length/2 of line to use as marker [ 0.05 ]
%      OPTIONS   plot options [ 'b' ]
%
%   output:
%      HANDLE   plotted line handle
%
%   example:
%      figure
%      h=mystem(1:.2:10,sin(1:.2:10),.2,'r');
%
%   MMA 2003, martinho@fis.ua.pt
%   Revision 10-2003

if nargin < 4
  options='b';
end
if nargin < 3
  r=.05;
end

X=[];
Y=[];
for i=1:length(x)
%  circlex=x(i)+r*cos(linspace(0,2*pi,20));
%  circley=y(i)+r*sin(linspace(0,2*pi,20));
  crossx=[x(i)-r x(i)+r];
  crossy=[y(i) y(i)];
  X=[X crossx nan x(i) x(i) nan];
  Y=[Y crossy nan y(i) 0 nan];
end

handle=plot(X,Y,options);
