function handles = north_arrow(lab,H,hh,tt,pos,rot,cL,cR,opt);
%NORTH_ARROW   Draw direction arrow
%   HANDLES = NORTH_ARROW(LAB,H,HH,TT,POS,ROT,CL,CR,OPT);
%
%         ^       ^    HH = h/H
%        /|\      |    o  = origin, pos
%       / | \
%      /  |  \    H
%     / / h \ \
%    /    o    \  |
%                 |
%    < -- b -- >  v
%
%   input:
%      LAB   text to insert at arrow tip [ 'N' ]
%      H     height [ 1 ]
%      HH    h/HH, see scheme above [ 0.3 ]
%      TT    angle (deg) [ 30 ]
%      POS   position, point o [ <x y> {<0 0>} ]
%      ROT   rotation [ 0 ]
%      CL    color to fill left side [ 'g' ]
%      CR    color to fill right side [ 'r' ]
%      OPT   plot options of the plotted lines [ 'k' ]
%
%   output:
%      HANDLES   handles to text, fill and plot
%
%   example:
%      figure
%      north_arrow
%      north_arrow('East')
%      north_arrow('W',1,.3,30,[1 1],30,'r','w','k');
%      axis equal, ylim([.8 2.2]);
%
%   MMA 13-8-2002, martinho@fis.ua.pt
%   Revision 10-2003

if nargin < 9,  opt = 'k';   end
if nargin < 8,  cR  = 'r';   end
if nargin < 7,  cL  = 'g';   end
if nargin < 6,  rot = 0;     end
if nargin < 5,  pos = [0 0]; end
if nargin < 4,  tt  = 30;    end
if nargin < 3,  hh  = .3;    end
if nargin < 2,  H   = 1;     end
if nargin < 1,  lab = 'N';   end


h2=hh*H;
tt=tt*pi/180;
b=2*tan(tt/2)*H;

X=[0 b/2 0 -b/2 0 0];
Y=[h2 0 H 0 h2 H];
[X,Y]=rot2d(X,Y,rot);
xL=[-b/2 0 0 -b/2];
yL=[0 h2 H 0];
[xL,yL]=rot2d(xL,yL,rot);
xR=[0 b/2 0 0];
yR=[h2 0 H h2];
[xR,yR]=rot2d(xR,yR,rot);

h=ishold;
handles.fillL=fill(xL+pos(1),yL+pos(2),cL); 
hold on
handles.fillR=fill(xR+pos(1),yR+pos(2),cR);
handles.plot=plot(X+pos(1),Y+pos(2),opt);
handles.text=text(X(3)+pos(1),Y(3)+pos(2),lab);
  set(handles.text,'HorizontalAlignment','center');
  set(handles.text,'VerticalAlignmen','bottom');
  ang=atan2(Y(2)-Y(4),X(2)-X(4))*180/pi;
  set(handles.text,'rotation',ang);


if ~h
  hold off
end
