function handle = plot_axis(x,y,z,options)
%PLOT_AXIS   Plot axes on current axis
%   HANDLE = PLOT_AXIS(X,Y,Z,OPTIONS)
%
%   input:
%      X         a line will be plotted between -X and X on xx axis
%      Y         a line will be plotted between -Y and Y on yy axis [ X ]
%      Z         a line will be plotted between -Z and Z on zz axis [ X ]
%      OPTIONS   line plot options [ 'k' ]
%
%   output:
%      HANDLE   plotted line handle
%
%   comment:
%      if Y and Z not specified, they will be X
%      if Z not specified the plot will be only xy (2D)
%
%   example:
%     h=plot_axis(1);
%
%   MMA 8-6-2003, martinho@fis.ua.pt
%   Revision 10-2003

if nargin < 4
  options='k';
end

zz=1;
if nargin == 1
  y=x;
  z=x;
end
if nargin == 2
  zz=0;
end

is = ishold;
hold on

if zz
  handle=plot3([-x x nan  0 0 nan  0 0],...
               [ 0 0 nan -y y nan  0 0],...
               [ 0 0 nan  0 0 nan -z z],options);
else
  handle=plot([-x x nan  0 0],...
              [ 0 0 nan -y y],options);
end

if ~is
  hold off
end
