function handle = sph2(pos,r,n,fcolor,ecolor)
%SPH2   Draw circle taking in account DataAspectRatio
%   HANDLE = SPH2(POS,R,N,FCOLOR,ECOLOR)
%   Well this is nothing more than a circle
%
%   input:
%      POS      center of the circle [ <x y z>, <x y> ]
%      R        radius, in the scale of axis with lower DataAspectRatio
%      N        number of points on the circumference [ 20 ]
%      FCOLOR   FaceColor [ 'blue' ]
%      ECOLOR   EdgeColor [ 'r' ]
%
%   output:
%      HANDLE   fill3 handle
%
%   example:
%      figure,peaks; hold on
%      sph2([1 0 9],1)
%      camlight
%
%   MMA 11 5 2004, martinho@fis.ua.pt
%   Modified 7-7-2004
%
%   See also SPH

if nargin < 5
  ecolor = 'r';
end
if nargin < 4
  fcolor = 'b';
end
if nargin < 3
  n = 20;
end


ar=get(gca,'DataAspectRatio');

tt = linspace(0,360,n+1);
x=cos(deg2rad(tt));
y=sin(deg2rad(tt));

x=x*r;
y=y*r;
%z=z*r;

x=x*ar(1)+pos(1);
y=y*ar(2)+pos(2);
%z=z*ar(3)+pos(3);
if length(pos) == 2
  pos(3)=0;
end
z=repmat(pos(3),size(x));

h=ishold;
hold on

handle=fill3(x,y,z,'b');
set(handle,'facecolor',fcolor,'edgecolor',ecolor);
set(gca,'DataAspectRatio',ar);

if ~h
  hold off
end
