function ud_handles(handle,direction)
%UD_HANDLES   Change position of current axis children
%   UD_HANDLES(HANDLE,DIRECTION)
%   Up-Down HANDLES is used to change position of some axis
%   children, ie, bring object forward, send object backward, 
%   move it to top or bottom
%   Without arguments a flipud in axis children is done
%   It my also be used with figure handles
%
%   input:
%      HANDLE      the handle to move
%      DIRECTION   the moving direction [ 'up' 'down' 'top' 'bottom' ]
%
%   example:
%      figure
%      h1=fill([0 1 2 0 ],[0 0 1 1 ],'g'); hold on
%      h2=plot([0 2],[.3 .3]);
%      h3=plot([0 2],[.35 .35],'r');
%      ud_handles(h2,'down') % send blue line backward:
%      ud_handles % flip
%
%   MMA 14-7-2004, martinho@fis.ua.pt

ax=gca;
handles=get(ax,'children');
n=length(handles);
if isempty(n)
  return
end

if nargin == 0 % case of flip
  set(ax,'children',flipud(handles));
  return
end

%------------- allow use of figure handles also:

parent = get(handle,'parent');
type = get(parent,'type');
if strcmpi(type,'axes')
  ax = gca;
elseif strcmpi(type,'figure')
  ax = gcf;
  handles=get(ax,'children');
  n=length(handles);
end
%--------------


if nargin == 1
  disp('## argument needed...');
  return
end

is=ismember(handles,handle);
i=find(is==1);
if isempty(i)
  return
end

if isequal(direction,'up') % bring object forward
  evalc('tmp=handles(i-1);','tmp=handles(i);');
  evalc('handles(i-1)=handles(i);','');
  handles(i)=tmp;
end

if isequal(direction,'down') % send object backward
  evalc('tmp=handles(i+1);','tmp=handles(i);');
  evalc('handles(i+1)=handles(i);','');
  handles(i)=tmp;
  handles=handles(1:n);
end

if isequal(direction,'top') % bring object to top
  tmp=handles(i);
  evalc('handles(2:i)=handles(1:i-1);','');
  handles(1)=tmp;
end

if isequal(direction,'bottom') % send object to bottom
  tmp=handles(i);
  evalc('handles(i:end-1)=handles(i+1:end);');
  handles(end)=tmp;
end

set(ax,'children',handles);
