function bat_smooth(NCgrid,hmin,hmax,r)
%BAT_SMOOTH   Smooth ROMS NetCDF grid file
%   BAT_SMOOTH(NCGRID,HMIN,HMAX,R)
%
%   input:
%      NCGRID   grid filename
%      HMIN     final minimum depth  [ 5 ]
%      HMAX     final maximum depth  [ inf ]
%      R        r factor (Beckmann and Haidvogel, 1993) [ 0.4 ]
%
%   result:
%      same grid with new h
%
%   comment:
%      may require hundreds of steps for some resolutions, bathymetries
%      and r factor
%      may not even converge !!! In this case some not clear changes are
%      to be done !!!
%      when prompted, automatic mode should be choosen
%      This function was created when I was just learning matlab, it
%      is very slow and has many unnecessary loops... maybe I will
%      optimise it one day... Nevertheless this function gives the
%      best results I have seen
%
%   requires:
%      m_hslope, modified version of hslope (Rutgers University)
%
%   MMA 2001, martinho@fis.ua.pt
%   Revision 10-2003
%
%   See also SMOOTH_R, M_HSLOPE

fname=NCgrid;

if nargin < 4
  VALOR = 0.4;
else
  VALOR=r;
end

if nargin < 3
  dmax = inf;
else
  dmax=hmax;
end

if nargin < 2
  dmin = 5;
else
  dmin=hmin;
end


n_s=0;  % number of smooth-steps
rn=0;   % vector with r of each step

disp('# Smooth of bathymetry from a Seagrid NetCDF grid');
disp(['# File: ',fname]);
disp(['# h min= ',num2str(dmin)]);
disp(['# h max= ',num2str(dmax)]);
disp(' ');
disp('# Initial conditions, see figures.');

nc=netcdf(fname,'write');
vv=var(nc);

[x,y,dhdx,dhde,slope,r]=m_hslope(fname,0,1);
rn(1)=max(max(r));
disp(['# r max initial= ',num2str(rn(1))]);
ss=input(['# Smooth Start. Automatic (1). Interactive (2). Stop (other) : ']);


if (ss~=1 & ss~=2)
  disp('# Stop without smooth');
  return
else
  close all

  while max(max(r)) > VALOR
    close all
    n_s=n_s+1;
    disp(' ')
    disp(['# Smoothing...for the time n=',int2str(n_s)]); 

    % smooth:
    %================================================================
    nc=netcdf(fname,'write');
    h=nc{'h'}(:);
    [m n]=size(h);
    hi=h;
    % valores minimos e maximos:
    h(find(h<=dmin))=dmin;
    h(find(h>=dmax))=dmax;
    h1=h;

    % alizamento de r a ser usado no alizamento:
    r(2:end+1,2:end+1)=r;  % WARNING: may not converge !!!
    r(1,:)=r(1,:);
    r(:,1)=r(:,2);

    for j=1:n
      for i=1:m
        if r(i,j)<.2
           r(i,j)=r(i,j)/1000;
        else
          r(i,j)=min(.25,r(i,j)/2);
        end
      end
    end
    r=smooth_r(r,3);

    for j=1:n 
      for i=1:m
        if n_s > 1
          E(i,j)=r(i,j); %edge;
          C(i,j)=1-r(i,j); %centre
          CC(i,j)=1-2*r(i,j);
        else
          %E(i,j)=.25;
          %C(i,j)=.75;
          %CC(i,j)=.5;
          E(i,j)=.1;
          C(i,j)=.9;
          CC(i,j)=.8;
        end
      end
    end


    % smooth ao longo de cada coluna:
    for j=1:n 
      for i=1:m
        if i==1
          h1(i,j)=C(i,j)*h(i,j)+E(i,j)*h(i+1,j);
        elseif i==m
          h1(i,j)=C(i,j)*h(i,j)+E(i,j)*h(i-1,j);
        else
          h1(i,j)=E(i,j)*(h(i-1,j)+h(i+1,j))+CC(i,j)*h(i,j);
        end
      end
    end

    h2=h1;
    % ao longo de cada linha:
    for i=1:m
      for j=1:n
        if j==1
          h2(i,j)=C(i,j)*h1(i,j)+E(i,j)*h1(i,j+1);
        elseif j==n
          h2(i,j)=C(i,j)*h1(i,j)+E(i,j)*h1(i,j-1);
        else
          h2(i,j)=E(i,j)*(h1(i,j-1)+h1(i,j+1))+CC(i,j)*h1(i,j);
        end
      end
    end
    %=====================================================================
    if ss==2
      figure(1),contour(hi,[21 50 100 200 500 1000]);
      title('h inicial');

      figure(2),contour(h1,[21 50 100 200 500 1000]),
      title('h aps alizamento na direco horizontal');

      figure(3),contour(h2,[21 50 100 200 500 1000]);
      title('h aps alizamento total');

      nw=input('# Pretende gravar no ficheiro .nc ;  s=1  ?');
    else
      nw=1;
    end
    if nw==1
      nc{'h'}(:)=h2;
    end
    nc=close(nc);
    disp(['# Result (figures) after ',int2str(n_s),' smooth-steps']);
    [x,y,dhdx,dhde,slope,r]=m_hslope(fname,0,1);
    rn(n_s+1)=max(max(r));
    disp(['# r max after ',int2str(n_s),' smooth-steps = ',num2str(rn(n_s+1))]);
    if ss==2
      go=input('# Pretende continuar ? (1)');
      if go~=1
        r=0;
      end
    end
  end
end
disp(' ')
disp(['# Final r= ',num2str(max(max(r)))]);
disp(['# Number or steps n= ',int2str(n_s)]);
disp(' ');
disp(['# Ensemble:']);
for i=1:(n_s+1)
 disp(['# Step ',int2str(i-1),' --> r= ',num2str(rn(i))]);
end
