function list = file_list(thedir,theext)
%FILE_LIST   List files of a directory
%   LIST = FILE_LIST(THEDIR,THEEXT)
%   If extension is specified, it also gives the files with that
%   extension
%
%   input:
%      THEDIR   directory to read [ <cd> ]
%      THEEXT   desired extension [ <none> ]
%
%   output:
%      LIST   structure with .dirs, .files and .files_ext (if THEEXT
%             is entered
%
%   example:
%     list = file_list;
%     list = file_list('/home/mma','nc');
%
%   MMA 11-10-2004, martinho@fis.ua.pt
%   2-12-2004, optimised

dirs  = [];
files = [];

if nargin == 0
  thedir = cd;
end

fprintf(1,'## getting list of files from dir = %s\n',thedir);
a = dir(thedir);
count_files = 0;
count_dirs  = 0;

for i=1:length(a)
  if a(i).isdir == 1
    count_dirs = count_dirs +1;
    dirs{count_dirs} = a(i).name;
  else
    count_files = count_files +1;
    files{count_files} = a(i).name;
  end
end

fprintf(1,'  # found %g dirs and %g files\n',count_dirs,count_files);

%---------------------------- deal with extensions:
if nargin == 2
  files_ext = [];
  count_files = 0;
  for i = 1:length(files)
    ext = explode(files{i},'.');
    ext = ext{end};
    if isequal(ext,theext)
      count_files = count_files +1;
      files_ext{count_files} = files{i};
    end
  end
  list.files_ext = files_ext;
  fprintf(1,'  # found %g files with extension %s\n',count_files,theext);
end

list.dirs  = dirs;
list.files = files;
