function name = freq2name(freq,display)
%FREQ2NAME   Convert tidal frequency to name
%   NAME = FREQ2NAME(FREQ,DISPLAY)
%
%   input:
%      FREQ      tidal component approximate frequency
%      DIAPLAY   show results   [ {0} | 1 ]
%
%   output:
%      NAME   tidal component name
%
%   comment:
%      T_TIDE file t_constituints.mat must be in path
%      T_TIDE is a Rich Pawlowicz's Matlab toolbox available at
%      http://www2.ocgy.ubc.ca/~rich/
%
%   example:
%      freq2name(1/12,1)
%
%   MMA 18-2-2003, martinho@fis.ua.pt
%   Revision 10-2003
%
%   See also NAME2FREQ

if nargin == 1
 display=0;
end

if exist('t_constituents.mat') ~= 2
  errordlg('t_constituents.mat not found (can be found in t_tide package)','missing...','modal');
else 
  load t_constituents
end

NAME=const.name;
FREQ=const.freq;

dist=(freq-FREQ).^2;
[d,i]=min(dist);
name=NAME(i,:);

if display
  disp(['# name of freq ',sprintf('%13.10f',freq),'  is  ',name]);
end
