function result = integ(x,y)
%INTEG   Riemann integration
%   RES = INTEG(X,Y)
%   Calculate numeric integral of y=f(x) 
%
%   input:
%      X, Y   vectors, Y=f(X)
%
%   example:
%      x=linspace(0,pi/2,10);
%      y=sin(x);
%      res=integ(x,y)
%
%   MMA 22-4-2002, martinho@fis.ua.pt
%   Revision 10-2003

if nargin ~=2 | length(x) ~= length(y)
  error('wrong input args...');
end

x=reshape(x,length(x),1);
y=reshape(y,length(y),1);

n=length(x);
xi=(x(2:end)+x(1:end-1))/2;
yi=interp1(x,y,xi);

dxi=x(2:end)-x(1:end-1);
result=sum(dxi.*yi);
