function ZI = interp2pi(X,Y,Z,XI,YI,opt,method)
%INTER2PI   Angles interpolation
%   ZI = INTERP2PI(X,Y,Z,XI,YI,OPT,METHOD)
%   Same as interp2 or griddata, but to deal with angles
%   The ain is avoid false discontinuities as in the case of interpolation
%   of an angle between 350 and 10. Interp2 would give 180, while correct
%   result is zero.
%
%   input:
%      X, Y, Z   original values
%      XI, YI    interpolation positions
%      OPT       use interp2 or griddata [ {'int'} | 'gri' ]
%      METHOD    interpolation method [ 'linear' ]
%
%   output:
%      ZI   interpolation of Z in XI x YI
%
%   comment:
%      see interp2 and griddata for additional help
%      METHOD must be compatible with OPT
%      Z and ZI are degrees
%
%   example:
%      x=1:10; y=1:10; [x,y]=meshgrid(x,y);
%      z=repmat([300:10:350 10:10:40]',1,10);
%      x1=1:.5:10; y1=1:.5:10; [x1,y1]=meshgrid(x1,y1);
%      z0=interp2(x,y,z,x1,y1);
%      z1=interp2pi(x,y,z,x1,y1);
%      subplot(2,2,1), pcolor(x,y,z), colorbar
%      subplot(2,2,2), pcolor(x1,y1,z0), colorbar
%      subplot(2,2,3), pcolor(x1,y1,z1), colorbar
%
%   MMA 11-9-2002, martinho@fis.ua.pt
%   Revision 10-2003
%
%   See also ATAN3

if nargin < 7
  method='linear';
end
if nargin < 6
   opt='int';
end

Z=Z*pi/180;
Zs=sin(Z);
Zc=cos(Z);

if opt(1:3)=='int'
  ZIc=interp2(X,Y,Zc,XI,YI);
  ZIs=interp2(X,Y,Zs,XI,YI);
elseif opt(1:3)=='gri'
  ZIc=griddata(X,Y,Zc,XI,YI,method);
  ZIs=griddata(X,Y,Zs,XI,YI,method);
else
  error('## opt is wrong.')
end

ZI=atan3(ZIs,ZIc);
