function is=isnumber(v,n,space)
%ISNUMBER   Check if numeric value
%   IS = ISNUMBER(V,N,SPACE)
%   IS = ISNUMBER(V,SPACE)
%   Similar to isnumeric but checks length, NaNs and range (space)
%
%   input:
%      V       data vector
%      N       desired length of vector [<-1>]
%              if -1, length is not checked
%      SPACE   allowed values (any by default):
%              'Z', 'Z+', 'Z0+', 'Z-', 'Z0-'
%              'R+', 'R0+', 'R-', 'R0-'
%
%   output:
%      IS   returns status, 0 or 1
%
%   example:
%      is=isnumber([1 2 3],3)   % 1
%      is=isnumber([1 2 3])     % 1
%      is=isnumber('www')       % 0
%      is=isnumber([1 2.1],'Z') % 0
%
%   MMA, 8-2003, martinho@fis.ua.pt
%   2-2-2005, allow argument SPACE

is=0;

if nargin == 1
  n = -1;
end

if nargin == 2 & isstr(n)
    n = -1;
    space = n;
end

if isempty(v)
  return;
end

if ~isnumeric(v)
  return
end

if  ~isequal(n,-1)
  if length(v)  ~= n
    return
  end
end

if any(isnan(v))
  return
end

if exist('space') == 1
  switch space
    case 'Z',   if ~all( v == floor(v)          ), return, end
    case 'Z-',  if ~all( v == floor(v) & v <  0 ), return, end
    case 'Z0-', if ~all( v == floor(v) & v <= 0 ), return, end
    case 'Z+',  if ~all( v == floor(v) & v >  0 ), return, end
    case 'Z0+', if ~all( v == floor(v) & v >= 0 ), return, end

    case 'R-',  if ~all(v <  0), return, end
    case 'R0-', if ~all(v <= 0), return, end
    case 'R+',  if ~all(v >  0), return, end
    case 'R0+', if ~all(v >= 0), return, end
  end
end

is=1;
