function mat_tex(m,varargin)
%MAT_TEX   Create latex table with matlab matrice
%   MAT_TEX(M,VARARGIN)
%
%   input:
%      M          2D array
%      VARARGIN:
%         'col1',   fist column, cell array
%         'line1',  fist line, cell array
%         'str',    table caption
%         'ps',     name of output ps file
%
%   comment:
%      requires the executables latex, dvips and gv
%
%   example:
%      m = [1 2; 3 4];
%      line1 = {'first col','second col'};
%      col1  = {'first line','second line'};
%      str   = 'this is the table caption';
%      ps    = 'my_psfile.ps';
%      mat_tex(m,'line1',line1,'col1',col1,'str',str,'ps',ps)
%
%   MMA 2004, martinho@fis.ua.pt

col1    = 0;
line1   = 0;
lines   = [];
cols    = [];
cstr    = '|';
psname  = [];
caption = [];

str = datestr(now,0);
str(str==' ') = '_';
str(str=='-') = '_';
str(str==':') = '_';
ftex    = ['temp_',str,'.tex'];

vin = varargin;
for i=1:length(vin)
  if isequal(vin{i},'line1')
    cols = vin{i+1};
  end
  if isequal(vin{i},'col1')
    lines = vin{i+1};
  end
  if isequal(vin{i},'ps')
    psname = vin{i+1};
  end
  if isequal(vin{i},'str')
    caption = vin{i+1};
  end
end

col1  = ~isempty(lines);
line1 = ~isempty(cols);

ncols=size(m,2);

if col1
  cstr = '|r||';
end

for j=1:ncols
  cstr=[cstr 'c|'];
end

fid=fopen(ftex,'w');

fprintf(fid,'%s\n','\documentclass{article}');
fprintf(fid,'%s\n','\begin{document}');
fprintf(fid,'%s\n','\begin{table}');
fprintf(fid,'%s\n','\centering');
fprintf(fid,'%s\n',['\begin{tabular}{',cstr,'}']);
fprintf(fid,'%s\n','\hline');

if line1
  fprintf(fid,'%s & ',' ');
  for j=1:size(m,2)-1
    fprintf(fid,'%s & ',cols{j});
  end
  fprintf(fid,'%s %s\n',cols{end},'\\');
  fprintf(fid,'%s\n','\hline\hline');
end

for i=1:size(m,1)
  if col1
    fprintf(fid,'%s & ',lines{i});
  end
  for j=1:size(m,2)-1
    fprintf(fid,'%2.2f %s',m(i,j),'& ');
  end
  fprintf(fid,'%2.2f %s\n',m(i,end),'\\');
  fprintf(fid,'%s\n','\hline');
end

fprintf(fid,'%s\n','\end{tabular}');
fprintf(fid,'%s\n',['\caption{',caption,'}']);
fprintf(fid,'%s\n','\end{table}');
fprintf(fid,'%s\n','\end{document}');

fclose(fid);

fdvi = [ftex(1:end-3),'dvi'];
fps  = [ftex(1:end-3),'ps'];
faux = [ftex(1:end-3),'aux'];
flog = [ftex(1:end-3),'log'];
if isempty(psname), psname = fps; end

eval(['! latex ',ftex]);
eval(['! dvips ',fdvi,' -o ',psname]);
eval(['delete ',faux],'');
eval(['delete ',flog],'');
eval(['delete ',fdvi],'');
eval(['delete ',ftex ],'');

if isequal(computer,'PCWIN')
  eval(['! "C:\Program Files\Ghostgum\gsview\gsview32.exe" ',psname],'');
else
  eval(['! gv ',psname],'');
end
