function freq = name2freq(name,display)
%NAME2FREQ   Convert tidal name to frequency
%   FREQ = FREQ2NAME(FREQ,DISPLAY)
%
%   input:
%      NAME      tidal component name
%      DIAPLAY   show results [ {0} | 1 ]
%
%   output:
%      FREQ   tidal component frequency
%
%   comment:
%      T_TIDE file t_constituints.mat must be in path
%      T_TIDE is a Rich Pawlowicz's Matlab toolbox available at
%      http://www2.ocgy.ubc.ca/~rich/
%
%   example:
%      freq=name2freq('M2',1)
%
%   MMA 29-9-2002, martinho@fis.ua.pt
%   Revision 10-2003
%
%   See also FREQ2NAME

if nargin == 1
    display=0;
end

if exist('t_constituents.mat') ~= 2
  errordlg('t_constituents.mat not found (can be found in t_tide package)','missing...','modaal');
  freq=NaN;
  return
else
  load t_constituents
end

NAME=const.name;
FREQ=const.freq;

L=min(length(name),4);

for i=1:length(FREQ)
  if strcmpi(NAME(i,1:L),name)
    ii=i;
  end
end

if exist('ii')
  freq=FREQ(ii);
  T=1/freq;
else
  freq=NaN;
  T=NaN;
end

if display
  disp(['# freq of ',name,' = ',sprintf('%13.10f',freq)]);
  disp(['# T of ',name,' = ',sprintf('%13.10f',T)]);
end
