function [x2,y2,z2]=rot3d(x,y,z,tt,fi)
%ROT3D   3D rotation
%   [X,Y,Z] = ROT3D(XI,YI,ZI,TETA,ELEVATION)
%   [V] = ROT3D(VI,TETA,ELEVATION)
%   Rotates matrice xi, yi and zi with teta and elevation
%
%   input:
%      XI, YI, ZI  initial positions, can by any size 2-D arrays, or
%      VI          VI = [XI,YI,ZI], with size=3xN or Nx3
%      TETA        rotation angle (deg)
%      ELEVATION   elevation angle (deg)
%
%   output:
%      X, Y, Z   rotated positions, or
%      V         V = [X,Y,Z]
%
%   example:
%      v=[1 0 0];
%      [v2]=rot3d(v,90,30);
%      plot3([-1 1 nan 0 0 nan 0 0],[0 0 nan -1 1 nan 0 0],[0 0 nan 0 0 nan -1 1]);
%      hold on, axis equal
%      plot3(v(1),v(2),v(3),'ko');
%      plot3(v2(1),v2(2),v2(3),'r*');
%      view([120 40])
%
%   MMA 13-1-2003, martinho@fis.ua.pt
%   Revision 10-2003
%   Corrected 7-7-2004
%
%   See also ROT2D

if nargin == 3
  v  = x;
  tt = y;
  fi = z;
elseif nargin == 5
  v=[x y z];
else
  disp('## wrong arguments...');
end


if nargin == 3 % in this case v must have m or n = 3
  [m,n]=size(v);
  if m ~= 3 & n == 3
    v=v';
  end
  v2 = rot(v,tt,fi);
  x2=v2(1,:);
  y2=v2(2,:);
  z2=v2(3,:);
  if nargout == 1
    x2 =v2;
  end
end

if nargin == 5 % allows any size for x (y or z)
  for i=1:size(x,1)
    for j=1:size(x,2)
      v=[x(i,j), y(i,j), z(i,j)];
      v2=rot(v',tt,fi);

      x2(i,j)=v2(1);
      y2(i,j)=v2(2);
      z2(i,j)=v2(3);
    end
  end
end

function v2 = rot(v,tt,fi)
tt=-tt*pi/180;
fi=-fi*pi/180;
Mz=[ cos(tt)  sin(tt)  0;
    -sin(tt)  cos(tt)  0;
           0        0  1];
My=[cos(fi)   0 sin(fi);
          0   1       0;
   -sin(fi)   0 cos(fi)];
M=Mz*My;
v2=M*v;
