function d = n_vararraydim(file,varname)
%N_VARARRAYDIM   Get array dimension of a NetCDF variable, range or size
%   D = N_VARARRAYDIM(FILE,VARNAME)
%   D = N_VARARRAYDIM(VARSIZE)
%   D = N_VARARRAYDIM(RANGE)
%
%   input:
%      FILE      NetCDF file
%      VARNAME   variable
%      VARSIZE   size of any variable (output of matlab size)
%      RANGE     string of ranges, ex: '1:2:10,10:10:100', '(a,b:c)'
%
%   output:
%      D   the dimension; -1 if variable is empty; 1 if vector; ...
%          [] if variable do not exist or if there is an error in
%          file
%
%   requires:
%      NetCDF interface for Matlab, when not using VARSIZE or RANGE
%
%   comment:
%      a variable with size = 0 10 10 returns dimension = -1
%
%   example:
%      out = n_vardim('filename.nc','lon')
%      out = n_vardim(size(ones(10,10)));
%      out = n_vardim('1:2:10,1:10');
%
%   MMA 7-6-2004, martinho@fis.ua.pt
%   7-2-5, improved
%
%   See also N_VARSIZE

d  = [];

if nargin == 1 & isstr(file) % then using range
  s = n_varsize(file);
elseif nargin == 2
  s = n_varsize(file,varname);
else
  s = file; % using varsize
end

if isempty(s)
  return
end

if all(s==1)
  d=0;
end

if any(s==0)
  d=-1;
else
  d=length(find(s>1));
end
