function out =  n_varattexist(file,varname,attname)
%N_VARATTEXIST   Check if NetCDF variable attribute exists
%   OUT = N_VARATTEXIST(FILE,VARNAME,ATTNAME)
%
%   input:
%      FILE      NetCDF file
%      VARNAME   variable
%      ATTNAME   attribute name
%
%   output:
%      OUT   1 = yes; 0 = no; [] = error in file or if VARNAME not
%            found
%
%   requires:
%      NetCDF interface for Matlab
%
%   example:
%      out = n_varattexist('file.nc','temp','units')
%
%   MMA 7-2-2005, martinho@fis.ua.pt
%
%   See also N_VARATT, N_FILEATT, N_FILEATTEXIST

out=[];

if nargin < 3
  disp('# arguments required');
  return
end

attrib = n_varatt(file,varname);

if isempty(attrib)
  return
end

out=0;
for i=1:length(attrib.name)
  if isequal(attrib.name{i},attname)
    out = 1;
    return
  end
end
