function out =  n_vardimexist(file,varname,dim)
%N_VARDIMEXIST   Check if NetCDF variable dimension exists
%   OUT = N_VARDIMEXIST(FILE,VARNAME,DIM)
%
%   input:
%      FILE      NetCDF file
%      VARNAME   variable
%      DIM       dimension name
%
%   output:
%      OUT   1 = yes; 0 = no; [] = error in file or if VARNAME not
%            found
%
%   requires:
%      NetCDF interface for Matlab
%
%   example:
%      out = n_vardimexist('file.nc','temp','eta_rho')
%
%   MMA 7-2-2005, martinho@fis.ua.pt
%
%   See also N_VARDIM, N_FILEDIM, N_FILEDIMEXIST

out=[];

if nargin < 3
  disp('# arguments required...');
  return
end

dims = n_vardim(file,varname);

if isempty(dims)
  return
end

out=0;
for i=1:length(dims.name)
  if isequal(dims.name{i},dim)
    out = 1;
    return
  end
end
