function v = use(file,varname)
%USE   Load NetCDF variable
%   V = USE(FILE,VARNAME))
%   V = USE(FILE)
%   V = USE(EXT)
%   Returns the values of NetCDF variable, including scale and offset
%   when present the attributes scale_factor and add_offset
%
%   input:
%      VARNAME   variable name   [ <none> ]
%      FILE      NetCDF file   [ <none> ]
%      EXT       file extension (selection)   [ '*.nc ]
%
%   output:
%      V   data of VARNAME (:)
%
%   comment:
%      works with the NetCDF toolbox available at
%      http://crusty.er.usgs.gov/~cdenham/MexCDF/nc4ml5.html
%      if scale or offset are present they are applied
%      The first input argument considered EXT if it starts by '*.',
%      so, use('file.nc') is using FILE, use('*.cdl')  is using EXT
%
%   example:
%      h = use;
%      h = use('*.cdf');
%      h = use('file.nc');
%      h = use('file.nc','variable');
%      h = use;
%
%   MMA, 2001. (martinho@fis.ua.pt)
%   7-2-2005, improved
%
%   See also SHOW

v = [];

get_file = 0;
get_var  = 0;
ext      = '*.nc';

if nargin == 0
  get_var = 1;
  get_file = 1;
end

if nargin == 1
  get_var = 1;

  % check if using file or ext:
  if isequal(file(1:2),'*.') % using ext
    ext = file;
    get_file = 1;
  end
end

if get_file
  [filename, pathname]=uigetfile(ext, 'Choose the NetCDF file');
  file=[pathname,filename];
  if isequal(filename,0)|isequal(pathname,0)
    return
  end
end

ncquiet;
nc = netcdf(file);
if isempty(nc)
  return
end

if get_var
  varname=input('# variable ? ','s');
end

if n_varexist(file,varname)
  v=nc{varname}(:);
else
  disp(['# variable ',varname,' not found']);
  return
end

close(nc);

% get scale and offset:
[scale,offset] = n_varscale(file,varname);

if n_varattexist(file,varname,'scale_factor'),  disp(['# scale  = ',num2str(scale)]);  end
if n_varattexist(file,varname,'add_offset'),    disp(['# offset = ',num2str(offset)]); end
